@@ -10,24 +10,25 @@ from django_nose import NoseTestSuiteRunner
 from django.conf import settings
 
 EXTERNAL_APPS = [
-    'django.contrib.admin',
-    'django.contrib.admindocs',
-    'django.contrib.auth',
-    'django.contrib.contenttypes',
-    'django.contrib.messages',
-    'django.contrib.sessions',
-    'django.contrib.staticfiles',
-    'django.contrib.sitemaps',
-    'django.contrib.sites',
+    "django.contrib.admin",
+    "django.contrib.admindocs",
+    "django.contrib.auth",
+    "django.contrib.contenttypes",
+    "django.contrib.messages",
+    "django.contrib.sessions",
+    "django.contrib.staticfiles",
+    "django.contrib.sitemaps",
+    "django.contrib.sites",
 ]
 INTERNAL_APPS = [
-    'django_nose',
-    'dbmi_client',
+    "django_nose",
+    "dbmi_client",
 ]
 INSTALLED_APPS = EXTERNAL_APPS + INTERNAL_APPS
 
 if not settings.configured:
     settings.configure(
+        SECRET_KEY="*4n1!z0%@w-e&u9c-kpyqof=-nxvx^v2m000#gf9vewm3s+_v)",
         DATABASES={
             "default": {
                 "ENGINE": "django.db.backends.sqlite3",
@@ -39,7 +40,7 @@ if not settings.configured:
             "CLIENT": "DBMI-Client",
             "ENVIRONMENT": "prod",
             "AUTH0_TENANTS": "hms-dbmi",
-        }
+        },
     )
 
 
@@ -47,5 +48,5 @@ def main(*test_args):
     sys.exit(NoseTestSuiteRunner(verbosity=2, interactive=True).run_tests(test_args))
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main(*sys.argv[1:])
